// vi: set ts=4 sw=4 :
// vim: set tw=75 :

// sdk_util.cpp - utility routines from HL SDK util.cpp

// Selected portions of dlls/util.cpp from SDK 2.1.
// Functions copied from there as needed...

/***
*
*	Copyright (c) 1999, 2000 Valve LLC. All rights reserved.
*	
*	This product contains software technology licensed from Id 
*	Software, Inc. ("Id Technology").  Id Technology (c) 1996 Id Software, Inc. 
*	All Rights Reserved.
*
*   Use, distribution, and modification of this source code and/or resulting
*   object code is restricted to non-commercial enhancements to products from
*   Valve LLC.  All other use, distribution, or modification is prohibited
*   without written permission from Valve LLC.
*
****/
/*

===== util.cpp ========================================================

  Utility code.  Really not optional after all.

*/

#include <string.h>			// for strncpy(), etc

#include <extdll.h>
#include <sdk_util.h>
#include <meta_api.h>
#include <time.h>

#include "demo_status.h"


char* UTIL_VarArgs( char *format, ... )
{
	va_list		argptr;
	static char	string[1024];
	
	va_start  (argptr, format);
	_vsnprintf(string, 1024, format, argptr);
	va_end    (argptr);
	
	string[sizeof(string)-1] = 0;

	return string;
}
	

//=========================================================
// UTIL_LogPrintf - Prints a logged message to console.
// Preceded by LOG: ( timestamp ) < message >
//=========================================================
void UTIL_LogPrintf( char *fmt, ... )
{
	va_list			argptr;
	static char		string[1024];
	
	va_start  ( argptr, fmt );
	_vsnprintf( string, 1024, fmt, argptr );
	va_end    ( argptr );
	
	string[sizeof(string)-1] = 0;

	// Print to server console
	ALERT( at_logged, "%s", string );
}


/**************************************************************
* 
* Alternative INDEXENT function with error checking
*
**************************************************************/
edict_t * INDEXENT2( int playerIndex )
{
	edict_t * pPlayer = NULL;

	if ( playerIndex > 0 && playerIndex <= gpGlobals->maxClients ) 
	{
		pPlayer = INDEXENT( playerIndex );
	}
	
	return pPlayer;
}


/**************************************************************
* 
* Alternative ENTINDEX2 function with error checking
*
**************************************************************/
int ENTINDEX2(edict_t *pEdict)
{
	if(pEdict)
	{
		int index = ENTINDEX(pEdict);
		if( index > 0 && index <= gpGlobals->maxClients )
			return(index);
	}
	
	return(0);
}


//returns current date and time in string format
const char * getdatetimestr(const char * format) {
	static char str[80];
	struct tm *time_now;
	time_t secs_now;
	
	if(!format)
		format = "%m/%d/%Y-%H:%M:%S";
	
	tzset();
	time(&secs_now);
		
	time_now = localtime(&secs_now);
	strftime(str, 80, format, time_now);
			
	return(str);
}